# EIDA Consistency Report: `UIB-NORSAR`

- Seed: `493182`
- Time: `2025-09-08T17:30:00.221786+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `20`
- Consistent: `18`
- Inconsistent: `2`
- Score: **90.0 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `2`

## Dataselect Response Types
- **NoTrace**: `3`
- **SingleTrace**: `17`

---

## Detailed Results
### `QE.HNB4..HHE`
- Window: `2023-05-19T03:11:25 → 2023-05-19T03:21:25`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NS.VERL.00.HHZ`
- Window: `2024-06-28T01:10:26 → 2024-06-28T01:20:26`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `NS.HAMF.00.HHE`
- Window: `2022-08-05T20:58:15 → 2022-08-05T21:08:15`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NS.KTK1.00.EHZ`
- Window: `2012-11-05T11:27:20 → 2012-11-05T11:37:20`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NS.JMIN.00.BHN`
- Window: `2006-05-07T03:35:19 → 2006-05-07T03:45:19`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NS.TBLU.00.HHE`
- Window: `2010-11-21T23:56:46 → 2010-11-22T00:06:46`
- Availability: `False`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `❌`

### `NS.OSL.00.EHE`
- Window: `2009-11-19T11:16:21 → 2009-11-19T11:26:21`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NS.BJO1.00.HHZ`
- Window: `2009-09-06T13:49:40 → 2009-09-06T13:59:40`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NS.AVER.00.HHZ`
- Window: `2028-08-06T04:26:38 → 2028-08-06T04:36:38`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `NS.SORF.00.CHE`
- Window: `2028-03-30T14:51:30 → 2028-03-30T15:01:30`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `NS.TRO.00.HHE`
- Window: `2010-03-01T01:21:36 → 2010-03-01T01:31:36`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NS.SOLFA.00.HHE`
- Window: `2025-05-25T05:07:54 → 2025-05-25T05:17:54`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NS.OSL.00.HHE`
- Window: `2027-07-25T15:08:16 → 2027-07-25T15:18:16`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `NO.NB204.00.SHZ`
- Window: `2009-08-15T06:07:50 → 2009-08-15T06:17:50`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NO.ARC5.00.SHZ`
- Window: `2009-06-10T10:15:43 → 2009-06-10T10:25:43`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NO.ARD5.00.BHZ`
- Window: `2021-03-24T07:00:32 → 2021-03-24T07:10:32`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NS.DOMB.00.EHE`
- Window: `2009-07-28T17:00:30 → 2009-07-28T17:10:30`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `NS.KONS.00.HHE`
- Window: `2024-02-21T11:49:21 → 2024-02-21T11:59:21`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `3R.KON06..HHN`
- Window: `2020-12-18T16:36:32 → 2020-12-18T16:46:32`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `1L.OBS03.00.HH1`
- Window: `2017-12-09T22:57:21 → 2017-12-09T23:07:21`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`
